@@ -1,13 +1,15 @@
+from PuppeteerLibrary.ikeywords.ialert_async import iAlertAsync
 from PuppeteerLibrary.base.librarycomponent import LibraryComponent
 from PuppeteerLibrary.base.robotlibcore import keyword
-from PuppeteerLibrary.keywords.alert_async import AlertKeywordsAsync
 
 
 class AlertKeywords(LibraryComponent):
 
     def __init__(self, ctx):
-        self.ctx = ctx
-        self.async_func = AlertKeywordsAsync(self.ctx)
+        super().__init__(ctx)
+
+    def get_async_keyword_group(self) -> iAlertAsync:
+        return self.ctx.get_current_library_context().get_async_keyword_group(type(self).__name__)
 
     @keyword
     def handle_alert(self, action, prompt_text=''):
@@ -23,5 +25,8 @@ class AlertKeywords(LibraryComponent):
         | ...    Handle Alert  | ACCEPT           | AND |
         | ...    Click Button  | id=alert_confirm |     |
 
+        Limitation:
+        Not support for webkit
+
         """
-        return self.loop.run_until_complete(self.async_func.handle_alert_async(action, prompt_text))
+        return self.loop.run_until_complete(self.get_async_keyword_group().handle_alert(action, prompt_text))
