@@ -1,13 +1,15 @@
-from PuppeteerLibrary.keywords.waiting_async import WaitingKeywordsAsync
-from PuppeteerLibrary.base.librarycomponent import LibraryComponent
 from PuppeteerLibrary.base.robotlibcore import keyword
+from PuppeteerLibrary.ikeywords.iwaiting_async import iWaitingAsync
+from PuppeteerLibrary.base.librarycomponent import LibraryComponent
 
 
 class WaitingKeywords(LibraryComponent):
 
     def __init__(self, ctx):
-        self.ctx = ctx
-        self.async_func = WaitingKeywordsAsync(self.ctx)
+        super().__init__(ctx)
+
+    def get_async_keyword_group(self) -> iWaitingAsync:
+        return self.ctx.get_current_library_context().get_async_keyword_group(type(self).__name__)
 
     @keyword
     def wait_for_request_url(self, url, method='GET', body=None, timeout=None):
@@ -32,6 +34,8 @@ class WaitingKeywords(LibraryComponent):
 
         The ``body`` is request body message. body can match using regexp
 
+        ``Return`` request msg  with properties {url, method, body}
+
         Example:
 
         | Open browser       | ${HOME_PAGE_URL}       | options=${options}   |      |               |
@@ -41,7 +45,7 @@ class WaitingKeywords(LibraryComponent):
         | ...                | `Wait For Request Url` | ${URL_API}/login     | POST | username=demo |
 
         """
-        return self.loop.run_until_complete(self.async_func.wait_for_request_url_async(url, method, body, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_for_request_url_async(url, method, body, timeout))
 
     @keyword
     def wait_for_response_url(self, url, status=200, body=None, timeout=None):
@@ -60,6 +64,8 @@ class WaitingKeywords(LibraryComponent):
         - 500
         Reference:[https://restfulapi.net/http-status-codes/|https://restfulapi.net/http-status-codes/]
 
+        ``Return`` request msg  with properties {url, status, body}
+
         Example:
 
         | Open browser       | ${HOME_PAGE_URL}        | options=${options}          |      |               |
@@ -69,10 +75,10 @@ class WaitingKeywords(LibraryComponent):
         | ...                | `Wait For Response Url` | ${URL_API}/login            | 200  | username=demo |
 
         """
-        return self.loop.run_until_complete(self.async_func.wait_for_response_url_async(url, status, body, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_for_response_url(url, status, body, timeout))
 
     @keyword
-    def wait_for_navigation(self):
+    def wait_for_navigation(self, timeout=None):
         """
         Waits until web page navigates to new url or reloads.
 
@@ -84,7 +90,7 @@ class WaitingKeywords(LibraryComponent):
         | Run Async Keywords | Click Element           | id:login_button             | AND  |
         | ...                | `Wait For Navigation`   |                             |      |
         """
-        return self.loop.run_until_complete(self.async_func.wait_for_navigation_async())
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_for_navigation(timeout))
 
     @keyword
     def wait_until_page_contains_element(self, locator, timeout=None):
@@ -96,7 +102,7 @@ class WaitingKeywords(LibraryComponent):
         | Open browser                       | ${HOME_PAGE_URL}        | options=${options} |
         | `Wait Until Page Contains Element` | id:username             |                    |
         """
-        return self.loop.run_until_complete(self.async_func.wait_for_selenium_selector(locator, timeout))
+        self.loop.run_until_complete(self.get_async_keyword_group().wait_until_page_contains_element(locator, timeout))
 
     @keyword
     def wait_until_element_is_hidden(self, locator, timeout=None):
@@ -109,7 +115,7 @@ class WaitingKeywords(LibraryComponent):
         | ...                                | Wait For Navigation     |                             |      |
         | `Wait Until Element Is Hidden`     | id:login_button         |                             |      |
         """
-        return self.loop.run_until_complete(self.async_func.wait_until_element_is_hidden_async(locator, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_element_is_hidden(locator, timeout))
 
     @keyword
     def wait_until_element_is_visible(self, locator, timeout=None):
@@ -122,7 +128,7 @@ class WaitingKeywords(LibraryComponent):
         | ...                                | Wait For Navigation     |                             |      |
         | `Wait Until Element Is Visible`    | id:welcome              |                             |      |
         """
-        return self.loop.run_until_complete(self.async_func.wait_until_element_is_visible_async(locator, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_element_is_visible(locator, timeout))
 
     @keyword
     def wait_until_page_contains(self, text, timeout=None):
@@ -135,7 +141,8 @@ class WaitingKeywords(LibraryComponent):
         | ...                                | Wait For Navigation           |                             |      |
         | `Wait Until Page Contains`         | Invalid user name or password |                             |      |
         """
-        return self.loop.run_until_complete(self.async_func.wait_until_page_contains_async(text, timeout))
+        self.loop.run_until_complete(self.get_async_keyword_group().wait_until_page_contains(text, timeout))
+        # return self.loop.run_until_complete(self.async_func.wait_until_page_contains_async(text, timeout))
 
     @keyword
     def wait_until_page_does_not_contains(self, text, timeout=None):
@@ -148,7 +155,7 @@ class WaitingKeywords(LibraryComponent):
         | ...                                 | Wait For Navigation           |                             |      |
         | `Wait Until Page Does Not Contains` | Please input your user name   |                             |      |
         """
-        return self.loop.run_until_complete(self.async_func.wait_until_page_does_not_contains_async(text, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_page_does_not_contains(text, timeout))
 
     @keyword
     def wait_until_element_contains(self, locator, text, timeout=None):
@@ -160,7 +167,7 @@ class WaitingKeywords(LibraryComponent):
         | Open browser                       | ${HOME_PAGE_URL}        | options=${options}          |
         | `Wait Until Element Contains`      | css:#container p        | Please input your user name |
         """
-        return self.loop.run_until_complete(self.async_func.wait_until_element_contains_async(locator, text, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_element_contains(locator, text, timeout))
 
     @keyword
     def wait_until_element_does_not_contains(self, locator, text, timeout=None):
@@ -173,5 +180,39 @@ class WaitingKeywords(LibraryComponent):
         | ...                                    | Wait For Navigation           |                             |      |
         | `Wait Until Element Does Not Contains` | css:#container p              | Please input your user name |      |
         """
-        return self.loop.run_until_complete(self.async_func.wait_until_element_does_not_contains_async(locator, text, timeout))
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_element_does_not_contains(locator, text, timeout))
 
+    @keyword
+    def wait_until_location_contains(self, expected, timeout=None):
+        """
+        Waits until the current URL contains `expected`.
+
+        The `expected` argument contains the expected value in url.
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_location_contains(expected, timeout))
+
+    @keyword
+    def wait_until_location_does_not_contains(self, expected, timeout=None):
+        """
+        Waits until the current URL does not contains `expected`.
+
+        The `expected` argument contains the expected value must not in url.
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_location_does_not_contains(expected, timeout))
+
+    @keyword
+    def wait_until_element_is_enabled(self, selenium_locator, timeout=None):
+        """
+        Waits until the specific element is Enabled.
+
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_element_is_enabled(selenium_locator, timeout))
+
+    @keyword
+    def wait_until_element_finished_animating(self, selenium_locator, timeout=None):
+        """
+        Waits until the specific element is finished animating.
+        Check by check element position.
+
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().wait_until_element_finished_animating(selenium_locator, timeout))
